Page 44 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 44

Home

    To swell a mob of insurrection, these brigands would
    go into the factories and workshops and compel the

    surround a person, hold him tightly under the arms, and
    carry him with them against his will.

    Money, wine, and hope of plunder fired the zeal of
    the criminals making up the hoards of brigands
    described as, "men of rapine and carnage, thirsting for
    blood and booty." In all of the major uprisings: the siege
    of the Bastille, the march on Versailles, the invasion of

    the Tuileries, the massacres of September, and the Reign
    of Terror, these brigands made up the hard core of the
    mobs. The bulk of the atrocities that occurred during the
    Revolution was carried out by these hired assassins.
    After the first successful uprising, Mirabeau asserted
    that, "with 100 louis one can make quite a good riot."
    To generate an atmosphere of hysteria among the
    inhabitants of Paris, a constant barrage of false rumors
    and outright lies emanated from the leaders of the
    Revolution. Amazing though it was, no matter how
    outrageous the lies, no matter how many rumors proved
    to be false, the people never seemed to catch on. This led

    From the very beginning the National Assembly
    showed no real intention of getting down to the real
    business of reforms. Every concession upon the part of
    the King and Nobles was met with a new outbreak of
    denunciation, outbreaks of violence, and increased

    39

    The French Revolution

    workers to follow them. On the streets they would

    one observer to state, "Thus it is in revolutions, one

    rascal writes and a hundred thousand fools believe."